@@ -1,7 +1,7 @@
 from .base_enum import BaseEnum
 
 
-class MapSort(BaseEnum):
+class EMapSort(BaseEnum):
     FIRST_PUBLISHED = "FIRST_PUBLISHED"
     LAST_PUBLISHED = "LAST_PUBLISHED"
     UPDATED = "UPDATED"
